@@ -22,7 +22,7 @@ import hashlib
 import glob
 from calculate.lib.datavars import Variable, VariableError, ReadonlyVariable
 from calculate.lib.utils.portage import isPkgInstalled
-from calculate.lib.utils.files import readFile
+from calculate.lib.utils.files import readFile, readFileEx
 from calculate.lib.utils.tools import get_best_nearest_resolution
 import calculate.lib.utils.device as device
 from calculate.lib.utils.common import (getVideoFromXorgLog,
